|PyPI| |Python| |Travis| |AppVeyor| |ReadTheDocs| |Coverage|

Description
===========
This package contains a collection of utility functions that were created by `@1313e`_.
Most functions were created for personal use, but have been changed and optimized to work for others as well.

.. _@1313e: https://github.com/1313e

How to install
==============
e13Tools can be found in the PyPI system, so ``pip install e13tools`` should suffice.

Dependencies
------------
e13Tools requires:

- ``python >= 3.5``,
- ``matplotlib >= 2.2.4``,
- ``numpy >= 1.8``.

The following packages are used by a few functions and therefore optional:

- ``astropy >= 1.3``.

.. |PyPI| image:: https://img.shields.io/pypi/v/e13Tools.svg?logo=pypi&logoColor=white&label=PyPI
   :target: https://pypi.python.org/pypi/e13Tools
   :alt: PyPI - Latest Release
.. |Python| image:: https://img.shields.io/pypi/pyversions/e13Tools.svg?logo=python&logoColor=white&label=Python
   :target: https://pypi.python.org/pypi/e13Tools
   :alt: PyPI - Python Versions
.. |Travis| image:: https://img.shields.io/travis/com/1313e/e13Tools/master.svg?logo=travis%20ci&logoColor=white&label=Travis%20CI
   :target: https://travis-ci.com/1313e/e13Tools
   :alt: Travis CI - Build Status
.. |AppVeyor| image:: https://img.shields.io/appveyor/ci/1313e/e13Tools/master.svg?logo=appveyor&logoColor=white&label=AppVeyor
   :target: https://ci.appveyor.com/project/1313e/e13Tools
   :alt: AppVeyor - Build Status
.. |ReadTheDocs| image:: https://img.shields.io/readthedocs/e13tools/latest.svg?logo=read%20the%20docs&logoColor=white&label=Docs
    :target: https://e13tools.readthedocs.io
    :alt: ReadTheDocs - Build Status
.. |Coverage| image:: https://img.shields.io/codecov/c/github/1313e/e13Tools/master.svg?logo=codecov&logoColor=white&label=Coverage
    :target: https://codecov.io/gh/1313e/e13Tools/branches/master
    :alt: CodeCov - Coverage Status
